@@ -146,7 +146,7 @@ def mask_classes(boxes, positive_mask, ignoring_mask):
     return boxes
 
 
-def match(boxes, prior_boxes, positive_iou=0.5, negative_iou=0.0):
+def match_beta(boxes, prior_boxes, positive_iou=0.5, negative_iou=0.0):
     """Matches each prior box with a ground truth box (box from `boxes`).
     It then selects which matched box will be considered positive e.g. iou > .5
     and returns for each prior box a ground truth box that is either positive
@@ -177,7 +177,7 @@ def match(boxes, prior_boxes, positive_iou=0.5, negative_iou=0.0):
     return matched_boxes
 
 
-def match2(boxes, prior_boxes, iou_threshold=0.5):
+def match(boxes, prior_boxes, iou_threshold=0.5):
     """Matches each prior box with a ground truth box (box from `boxes`).
     It then selects which matched box will be considered positive e.g. iou > .5
     and returns for each prior box a ground truth box that is either positive
@@ -504,3 +504,18 @@ def to_normalized_coordinates(boxes, image):
     normalized_boxes[:, 1] = boxes[:, 1] / height
     normalized_boxes[:, 3] = boxes[:, 3] / height
     return normalized_boxes
+
+
+def extract_bounding_box_corners(points3D):
+    """Extracts the (x_min, y_min, z_min) and the (x_max, y_max, z_max)
+        coordinates from an array of  points3D
+    # Arguments
+        points3D: Array (num_points, 3)
+
+    # Returns
+        Left-down-bottom corner (x_min, y_min, z_min) and right-up-top
+            (x_max, y_max, z_max) corner.
+    """
+    XYZ_min = np.min(points3D, axis=0)
+    XYZ_max = np.max(points3D, axis=0)
+    return XYZ_min, XYZ_max
