@@ -7,9 +7,12 @@ from .keypoint.keypointnet import KeypointNetShared
 from .keypoint.keypointnet import KeypointNet2D
 from .keypoint.hrnet import HRNetResidual
 from .keypoint.hrnet import HRNetDense
+from .keypoint.detnet import DetNet
+from .keypoint.iknet import IKNet
 from .classification import build_xception
 from .classification import MiniXception
 from .segmentation import UNET
 from .segmentation import UNET_VGG16
 from .segmentation import UNET_VGG19
 from .segmentation import UNET_RESNET50
+from .pose_estimation import HigherHRNet
