@@ -2,6 +2,7 @@ import numpy as np
 
 from ..abstract import Processor
 from ..backend.boxes import to_one_hot
+from ..backend.standard import append_values
 
 
 class ControlMap(Processor):
@@ -410,3 +411,62 @@ class Stochastic(Processor):
         if self.probability >= np.random.rand():
             return self.function(X)
         return X
+
+
+class UnwrapDictionary(Processor):
+    """Unwraps a dictionry into a list given the key order.
+    """
+    def __init__(self, keys):
+        super(UnwrapDictionary, self).__init__()
+        self.keys = keys
+
+    def call(self, dictionary):
+        return [dictionary[key] for key in self.keys]
+
+
+class Scale(Processor):
+    """Scales an input.
+    """
+    def __init__(self, scales):
+        super(Scale, self).__init__()
+        self.scales = scales
+
+    def call(self, values):
+        return self.scales * values
+
+
+class AppendValues(Processor):
+    """Append dictionary values to lists
+
+    # Arguments
+        keys: Keys to dictionary values
+    """
+    def __init__(self, keys):
+        super(AppendValues, self).__init__()
+        self.keys = keys
+
+    def call(self, dictionary, lists):
+        return append_values(dictionary, lists, self.keys)
+
+
+class BooleanToTextMessage(Processor):
+    """Convert a boolean to text message.
+    # Arguments
+        true_message: String. Message for true case.
+        false_message: String. Message for false case.
+        Flag: Boolean.
+
+    # Returns
+        message: String.
+    """
+    def __init__(self, true_message, false_message):
+        super(BooleanToTextMessage, self).__init__()
+        self.true_message = true_message
+        self.false_message = false_message
+
+    def call(self, flag):
+        if flag:
+            message = self.true_message
+        else:
+            message = self.false_message
+        return message
